#oodist: *** DO NOT USE THIS VERSION FOR PRODUCTION ***
#oodist: This file contains OODoc-style documentation which will get stripped
#oodist: during its release in the distribution.  You can use this file for
#oodist: testing, however the code of this development version may be broken!

package HTML::FromMail::Page;
use base 'HTML::FromMail::Object';

use strict;
use warnings;

#--------------------
=chapter NAME

HTML::FromMail::Page - base class for outputting pages

=chapter SYNOPSIS

=chapter DESCRIPTION

=chapter METHODS

=section Constructors

=c_method new %options
=cut

#-----------
=section Attributes
=cut

#-----------
=section Other methods

=method lookup $label, \%options
Look-up, in a formatter dependent way, what the value related to a certain
$label is.  The location which is being produced on the moment that this
method is called is stored somewhere in the OPTIONS.  The formatter
(which is also in the %options) is called to get the value based on that
location information.

=requires formatter $object
=cut

sub lookup($$)
{	my ($self, $label, $args) = @_;
	$args->{formatter}->lookup($label, $args);
}

1;
